.. _spkg_overrides:

overrides: Decorator to automatically detect mismatch when overriding a method
==============================================================================

Description
-----------

Decorator to automatically detect mismatch when overriding a method

License
-------

Apache License, Version 2.0

Upstream Contact
----------------

https://pypi.org/project/overrides/



Type
----

standard


Dependencies
------------

- $(PYTHON)
- :ref:`spkg_pip`

Version Information
-------------------

package-version.txt::

    7.7.0

version_requirements.txt::

    overrides

Installation commands
---------------------

.. tab:: PyPI:

   .. CODE-BLOCK:: bash

       $ pip install overrides

.. tab:: Sage distribution:

   .. CODE-BLOCK:: bash

       $ sage -i overrides

.. tab:: mingw-w64:

   .. CODE-BLOCK:: bash

       $ sudo pacman -S ${MINGW_PACKAGE_PREFIX}-python-overrides


If the system package is installed and if the (experimental) option
``--enable-system-site-packages`` is passed to ``./configure``, then 
``./configure`` will check if the system package can be used.
